@@ -6,15 +6,9 @@ echo $PY_VERSION
 
 . ./clean.sh
 
-. ./build_011.sh
-zip -r ../testman4trac.$VER-Py_$PY_VERSION-Trac_0.11.zip bin
-tar cvzf ../testmanager.$VER-Py_$PY_VERSION-Trac_0.11.tar.gz bin
-
-. ./clean.sh
-
 . ./build.sh
-zip -r ../testman4trac.$VER-Py_$PY_VERSION-Trac_0.12-1.0.zip bin
-tar cvzf ../testmanager.$VER-Py_$PY_VERSION-Trac_0.12-1.0.tar.gz bin
+zip -r ../testman4trac.$VER-Py_$PY_VERSION-Trac_0.12-1.0.zip bin docs
+tar cvzf ../testmanager.$VER-Py_$PY_VERSION-Trac_0.12-1.0.tar.gz bin docs
 
 . ./clean.sh
 
